@@ -24,16 +24,25 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <KCmdLineArgs>
 #include <KLocale>
 
-// Locale
+// Qt
+#include <QScopedPointer>
+
+// Local
 #include "notificationmanager.h"
 #include "about.h"
 
 int main(int argc, char **argv)
 {
-    KAboutData* about = createAboutData();
-    KCmdLineArgs::init(argc, argv, about);
+    QScopedPointer<KAboutData> about(createAboutData());
+    KCmdLineArgs::init(argc, argv, about.data());
+
+    KCmdLineOptions options;
+    options.add("single", ki18n("Quit after one popup. Only useful when running with Valgrind"));
+    KCmdLineArgs::addCmdLineOptions(options);
+    KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
 
     KApplication app;
+    app.setQuitOnLastWindowClosed(args->isSet("single"));
     Colibri::NotificationManager manager;
     if (!manager.connectOnDBus()) {
         return 1;
