@@ -156,7 +156,7 @@ static int timeoutForText(const QString& text)
 {
     const int AVERAGE_WORD_LENGTH = 6;
     const int WORD_PER_MINUTE = 250;
-    return 60000 * text.length() / AVERAGE_WORD_LENGTH / WORD_PER_MINUTE;
+    return 1000 + 60000 * text.length() / AVERAGE_WORD_LENGTH / WORD_PER_MINUTE;
 }
 
 uint NotificationManager::Notify(const QString& appName, uint replacesId, const QString& appIcon, const QString& summary, const QString& body, const QStringList& /*actions*/, const QVariantMap& hints, int /*timeout*/)
@@ -193,10 +193,7 @@ uint NotificationManager::Notify(const QString& appName, uint replacesId, const
         image = decodeNotificationSpecImageHint(arg);
     }
 
-    // timeout
-    // Add two seconds for the user to notice the notification, and ensure it
-    // last at least five seconds, otherwise all the user sees is a flash
-    int timeout = 2000 + qMax(timeoutForText(summary + body), 3000);
+    int timeout = qBound(2000, timeoutForText(summary + body), 20000);
 
     // Id
     uint id = mNextId++;
@@ -213,7 +210,8 @@ uint NotificationManager::Notify(const QString& appName, uint replacesId, const
     if (mWidgets.size() == 1) {
         widget->start();
     }
-    kDebug() << "id:" << id << "app:" << appName << "summary:" << summary << "body:" << body;
+    kDebug() << "id:" << id << "app:" << appName << "summary:" << summary << "timeout:" << timeout;
+    kDebug() << "body:" << body;;
     return id;
 }
 
@@ -254,6 +252,10 @@ void NotificationManager::slotNotificationWidgetClosed(uint id, uint reason)
         return;
     }
     NotificationWidget* widget = mWidgets.takeFirst();
+
+    // Hack to workaround blinking when the notification is fading out
+    // See https://bugs.kde.org/show_bug.cgi?id=314427
+    widget->move(-widget->width(), 0);
     widget->deleteLater();
 
     if (!mWidgets.isEmpty()) {
