@@ -23,24 +23,29 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #ifndef NOTIFICATIONWIDGET_H
 #define NOTIFICATIONWIDGET_H
 
+// Qt
 #include <QPropertyAnimation>
 #include <QScopedPointer>
 #include <QWidget>
 
-class QLabel;
+// KDE
+#include <Plasma/Dialog>
+
+class QGraphicsScene;
 class QTimeLine;
 class QTimer;
 
+class HLayout;
+
 namespace Plasma
 {
 class FrameSvg;
+class Label;
 }
 
 namespace Colibri
 {
 
-class Label;
-
 class NotificationWidget;
 
 class State : public QObject
@@ -92,9 +97,9 @@ private Q_SLOTS:
 };
 
 /**
- * A widget which shows an notification
+ * A widget which shows a notification
  */
-class NotificationWidget : public QWidget
+class NotificationWidget : public Plasma::Dialog
 {
     Q_OBJECT
 public:
@@ -129,11 +134,6 @@ public:
 Q_SIGNALS:
     void closed(uint id, uint reason);
 
-protected:
-    virtual void paintEvent(QPaintEvent*);
-    virtual void resizeEvent(QResizeEvent*);
-    virtual void showEvent(QShowEvent*);
-
 private Q_SLOTS:
     void updateOpacity();
     void updateMouseOverOpacity();
@@ -145,12 +145,16 @@ private:
     QString mBody;
     QTimeLine* mVisibleTimeLine;
 
-    Label* mTextLabel;
+    QGraphicsScene* mScene;
+    QGraphicsWidget* mContainer;
+    QScopedPointer<HLayout> mHLayout;
+    Plasma::Label* mIconLabel;
+    Plasma::Label* mTextLabel;
+    Plasma::FrameSvg* mBackgroundSvg;
 
     uint mCloseReason;
     Qt::Alignment mAlignment;
     int mScreen;
-    Plasma::FrameSvg* mBackground;
 
     State* mState;
 
